AppService class

Constructors

AppService({int nodeType, String apiUrl, String keyApp})

Properties

apiUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyApp String
getter/setter pair
logger ↔ Logger
getter/setter pair
nodeType int
getter/setter pair
requestHeaders Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sshClient SSHClient
getter/setter pair

Methods

activateInvitation(String key, String address) Future<DnaActivateInviteResponse>
becomeOffline() Future<DnaBecomeOfflineResponse>
becomeOnline() Future<DnaBecomeOnlineResponse>
checkAddressIdena(String address) Future<bool>
checkSync() Future<BcnSyncingResponse>
getAddressTxsResponse(String address, int count) Future<BcnTransactionsResponse>
getBalanceGetResponse(String address) Future<DnaGetBalanceResponse>
getCurrentPeriod() Future<String>
getDnaCeremonyIntervals() Future<DnaCeremonyIntervalsResponse>
getDnaGetCoinbaseAddr(String addressByDefault) Future<DnaGetCoinbaseAddrResponse>
getDnaGetEpoch() Future<DnaGetEpochResponse>
getDnaIdentity(String address) Future<DnaIdentityResponse>
getFeePerGas() Future<int>
getFeesEstimation() double
getLastNonce(String address) Future<int>
getMemPool(String address) Future<BcnMempoolResponse>
getTransaction(String hash, String address) Future<BcnTransactionResponse>
getWStatusGetResponse() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInvitation(String address, String amount, int nonce, int epoch) Future<DnaSendInviteResponse>
sendRawTx(String rawTxSigned) Future<BcnSendRawTxResponse>
sendTip(String from, String amount, String seed) Future<DnaSendTransactionResponse>
sendTx(String from, String amount, String to, String privateKey, String payload) Future<DnaSendTransactionResponse>
signin(DeepLinkParamSignin deepLinkParam, String privateKey) Future<DeepLinkParamSignin>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited