Param class

Constructors

Param({String from, String to, String amount, String maxFee, String tips, String payload})
Param.fromJson(Map<String, dynamic> json)
factory

Properties

amount String
getter/setter pair
from String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxFee String
getter/setter pair
payload String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tips String
getter/setter pair
to String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited