ShortAnswer class

Constructors

ShortAnswer({String hash, int answer, bool wrongWords})
ShortAnswer.fromJson(Map<String, dynamic> json)
factory

Properties

answer int
getter/setter pair
hash String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrongWords bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited