Tx class

Constructors

Tx({String amount, Data data, String fee, String from, String hash, String maxFee, int size, DateTime timestamp, String tips, String to, String type})
Tx.fromJson(Map<String, dynamic> json)
factory

Properties

amount String
getter/setter pair
data Data
getter/setter pair
fee String
getter/setter pair
from String
getter/setter pair
hash String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxFee String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair
timestamp DateTime
getter/setter pair
tips String
getter/setter pair
to String
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited