createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoAnswersDb createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoAnswersDb createEmptyInstance() => create();