createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoBlockHeader createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoBlockHeader createEmptyInstance() => create();