createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoBlockHeader_Proposed createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoBlockHeader_Proposed createEmptyInstance() => create();