createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoChangeProfileAttachment createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoChangeProfileAttachment createEmptyInstance() => create();