createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoFlipKey createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoFlipKey createEmptyInstance() => create();