createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoIdentityStateDiff_IdentityStateDiffValue createEmptyInstance() =>
create();
Creates an empty instance of the same message type as this.
ProtoIdentityStateDiff_IdentityStateDiffValue createEmptyInstance() =>
create();