createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoProfile createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoProfile createEmptyInstance() => create();