createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoProposeProof createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoProposeProof createEmptyInstance() => create();