createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoSavedTransaction createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoSavedTransaction createEmptyInstance() => create();