createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoShortAnswerDb createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoShortAnswerDb createEmptyInstance() => create();