createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoStateAccount createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoStateAccount createEmptyInstance() => create();