createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoStateAccount_ProtoContractData createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoStateAccount_ProtoContractData createEmptyInstance() => create();