createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoStateGlobal createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoStateGlobal createEmptyInstance() => create();