createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoStateIdentity_Flip createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoStateIdentity_Flip createEmptyInstance() => create();