createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoTransaction_Data createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoTransaction_Data createEmptyInstance() => create();