createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ProtoUpgradeVotes createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ProtoUpgradeVotes createEmptyInstance() => create();