copyWith method

  1. @Deprecated('Using this can add significant overhead to your binary. ' 'Use [GeneratedMessageGenericExtensions.rebuild] instead. ' 'Will be removed in next major version')
ProtoVote_Data copyWith(
  1. void updates(
    1. ProtoVote_Data
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('Using this can add significant overhead to your binary. '
    'Use [GeneratedMessageGenericExtensions.rebuild] instead. '
    'Will be removed in next major version')
ProtoVote_Data copyWith(void Function(ProtoVote_Data) updates) =>
    super.copyWith((message) => updates(message as ProtoVote_Data))
        as ProtoVote_Data;