SocketAdaptorStreamConsumer class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socket SocketAdaptor
final
streamCompleter Completer
getter/setter pair
subscription StreamSubscription
getter/setter pair

Methods

addStream(Stream<List<int>> stream) Future<Socket>
Consumes the elements of stream.
override
close() Future<Socket>
Tells the consumer that no further streams will be added.
override
done([dynamic error, dynamic stackTrace]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited